==> kubernetes-client-4.13.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/node/v1beta1/RuntimeClassOperationsImpl.java <==

                                          
  

package io.fabric8.kubernetes.client.dsl.internal.node.v1beta1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.node.v1beta1.DoneableRuntimeClass;
import io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClass;
import io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassList;
import io.fabric8.kubernetes.api.model.node.v1beta1.DoneableRuntimeClass;

import java.util.Map;
import java.util.TreeMap;


public class RuntimeClassOperationsImpl extends HasMetadataOperation<RuntimeClass, RuntimeClassList, DoneableRuntimeClass, Resource<RuntimeClass, DoneableRuntimeClass>> {

  public RuntimeClassOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public RuntimeClassOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public RuntimeClassOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("node.k8s.io")
    .withApiGroupVersion("v1beta1")
    .withPlural("runtimeclasses"));
    this.type = RuntimeClass.class;
    this.listType = RuntimeClassList.class;
    this.doneableType = DoneableRuntimeClass.class;
  }

  public RuntimeClassOperationsImpl newInstance(OperationContext context) {
    return new RuntimeClassOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> kubernetes-client-5.4.2-sources.jar: io/fabric8/kubernetes/client/dsl/internal/node/v1beta1/RuntimeClassOperationsImpl.java <==

                                          
  

package io.fabric8.kubernetes.client.dsl.internal.node.v1beta1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClass;
import io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassBuilder;
import io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassList;

import java.util.Map;
import java.util.TreeMap;


public class RuntimeClassOperationsImpl extends HasMetadataOperation<RuntimeClass, RuntimeClassList, Resource<RuntimeClass>> {

  public RuntimeClassOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public RuntimeClassOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public RuntimeClassOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("node.k8s.io")
    .withApiGroupVersion("v1beta1")
    .withPlural("runtimeclasses"));
    this.type = RuntimeClass.class;
    this.listType = RuntimeClassList.class;
  }

  public RuntimeClassOperationsImpl newInstance(OperationContext context) {
    return new RuntimeClassOperationsImpl(context);
  }

  @Override
  public RuntimeClass edit(Visitor... visitors) {
    return patch(new RuntimeClassBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
